@@ -170,7 +170,7 @@ z_io_connect_connected(gboolean timed_out, gpointer data)
  *
  * This function is registered as the destroy notify function of @self when
  * the associated #ZSocketSource source is destroyed. It calls our
- * destroy_notify callback, and unrefs @self.
+ * destroy_notify callback, and unrefs self.
  *
  **/
 static void
@@ -389,7 +389,7 @@ z_io_connect_start_block(ZIOConnect *s)
  * @s: ZIOConnect instance
  * @context: GMainContext to use for polling
  *
- * Same as z_io_connect_start() but using the context specified in @context.
+ * Same as z_io_connect_start() but using the context specified in context.
  *
  * Returns: the local address we were bound to
  **/
@@ -424,11 +424,23 @@ z_io_connect_cancel(ZIOConnect *s)
   g_static_rec_mutex_lock(&self->lock);
   if(self->watch)
     {
-      g_source_destroy(self->watch);
-      g_source_unref(self->watch);
+      /* Must unlock self->lock before call g_source_destroy,
+       * because in another thread we may be hold context lock
+       * (inside the glib) and wait for this lock. (For example if
+       * the client stop the download in exactly the same time, when
+       * the connection failed.
+       */
+      GSource *watch = self->watch;
       self->watch = NULL;
+      g_static_rec_mutex_unlock(&self->lock);
+
+      g_source_destroy(watch);
+      g_source_unref(watch);
+    }
+  else
+    {
+      g_static_rec_mutex_unlock(&self->lock);
     }
-  g_static_rec_mutex_unlock(&self->lock);
   z_leave();
 }
 
@@ -438,7 +450,7 @@ z_io_connect_cancel(ZIOConnect *s)
  * @timeout: timeout in milliseconds
  *
  * Set connection timeout. The connection establishment may not exceed the
- * time specified in @timeout.
+ * time specified in timeout.
  * 
  **/
 void
@@ -470,6 +482,7 @@ z_io_connect_set_destroy_notify(ZIOConnect *s, GDestroyNotify notify)
  * @local: local address to bind to.
  * @remote: remote address to connect to.
  * @sock_flags: 
+ * @tos: Type of Service flag.
  * @callback: function to call when the connection is established.
  * @user_data: opaque pointer to pass to callback.
  *
@@ -535,7 +548,7 @@ z_io_connect_new(const gchar *session_id,
  * @s: ZIOConnect instance to free
  *
  * This function is called by z_io_connect_unref() when the reference count
- * of @s goes down to zero. It frees the contents of @s.
+ * of @s goes down to zero. It frees the contents of s.
  **/
 static void 
 z_io_connect_free(ZIOConnect *s)
@@ -577,7 +590,7 @@ z_io_connect_free(ZIOConnect *s)
  * z_io_connect_ref:
  * @s: ZIOConnect instance
  *
- * Increment the reference count of @s.
+ * Increment the reference count of s.
  **/
 void
 z_io_connect_ref(ZIOConnect *s)
