@@ -226,6 +226,7 @@ z_ssl_verify_crl(int ok,
        */
       BIO *bio;
       char *cp;
+      EVP_PKEY *pkey;
       int n, i;
 
       bio = BIO_new(BIO_s_mem());
@@ -246,7 +247,8 @@ z_ssl_verify_crl(int ok,
        */      
       z_log(session_id, CORE_DEBUG, 6, "Verifying CA CRL; issuer='%s', %s", subject_name, cp);
 
-      if (X509_CRL_verify(crl, X509_get_pubkey(xs)) <= 0)
+      pkey = X509_get_pubkey(xs);
+      if (X509_CRL_verify(crl, pkey) <= 0)
         {
           /*LOG
             This message indicates an invalid Certificate Revocation List (CRL),
@@ -255,9 +257,11 @@ z_ssl_verify_crl(int ok,
           z_log(session_id, CORE_ERROR, 1, "Invalid signature on CRL; issuer='%s'", subject_name);
           X509_STORE_CTX_set_error(ctx, X509_V_ERR_CRL_SIGNATURE_FAILURE);
           X509_OBJECT_free_contents(&obj);
+          EVP_PKEY_free(pkey);
           z_leave();
           return FALSE;
         }
+      EVP_PKEY_free(pkey);
 
       i = X509_cmp_current_time(X509_CRL_get_nextUpdate(crl));
       if (i == 0)
