@@ -35,21 +35,21 @@ gboolean z_fd_set_our_tos(gint fd, gint tos);
 #else
 
 static inline gboolean
-z_fd_get_peer_tos(gint fd, gint *tos)
+z_fd_get_peer_tos(gint fd G_GNUC_UNUSED, gint *tos)
 {
   *tos = -1;
   return TRUE;
 }
 
 static inline gboolean
-z_fd_get_our_tos(gint fd, gint *tos)
+z_fd_get_our_tos(gint fd G_GNUC_UNUSED, gint *tos)
 {
   *tos = -1;
   return TRUE;
 }
 
 static inline G_GNUC_CONST gboolean
-z_fd_set_our_tos(gint fd, gint tos)
+z_fd_set_our_tos(gint fd G_GNUC_UNUSED, gint tos G_GNUC_UNUSED)
 {
   return TRUE;
 }
